@@ -1,6 +1,8 @@
 package cli
 
 import (
+	"os"
+
 	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/cli/auth"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
@@ -10,14 +12,16 @@ import (
 )
 
 var authCmd = &cobra.Command{
-	Use:   "auth [ytmda]",
+	Use:   "auth [service]",
 	Short: "Authenticate against a service",
 	Long: `Authenticate against a service.
 
 Available services:
 
+- copilot: GitHub Copilot API
 - ytmda: YouTube Music Desktop App (YTMDA) API`,
 	ValidArgs: []string{
+		"copilot",
 		"ytmda",
 	},
 	Args: NoArgsOrOneValidArg,
@@ -28,19 +32,25 @@ Available services:
 		}
 
 		flags := &runtime.Flags{
-			Shell: shellName,
+			Shell: os.Getenv("POSH_SHELL"),
 		}
 
 		env := &runtime.Terminal{}
 		env.Init(flags)
 
-		cache.Init(shellName, true)
+		cache.Init(env.Shell(), cache.Persist)
 
 		defer func() {
 			cache.Close()
 		}()
 
 		switch args[0] {
+		case "copilot":
+			authenticator := auth.NewCopilot(env)
+			if err := auth.Run(authenticator); err != nil {
+				log.Error(err)
+				exitcode = 70
+			}
 		case "ytmda":
 			authenticator := auth.NewYtmda(env)
 			if err := auth.Run(authenticator); err != nil {
