@@ -4,21 +4,22 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/cli/upgrade"
 	"github.com/jandedobbeleer/oh-my-posh/src/color"
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/segments"
+	"github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 )
 
-func Default(warning bool) *Config {
+func Default(configError error) *Config {
 	exitBackgroundTemplate := "{{ if gt .Code 0 }}p:red{{ end }}"
 	exitTemplate := " {{ if gt .Code 0 }}\uf00d{{ else }}\uf00c{{ end }} "
 
-	if warning {
+	if configError != nil && configError != ErrNoConfig {
 		exitBackgroundTemplate = "p:red"
-		exitTemplate = " CONFIG ERROR "
+		exitTemplate = configError.Error()
 	}
 
 	cfg := &Config{
-		Version:    3,
+		hash:       1234567890, // placeholder hash value
+		Version:    4,
 		FinalSpace: true,
 		Blocks: []*Block{
 			{
@@ -40,8 +41,8 @@ func Default(warning bool) *Config {
 						PowerlineSymbol: "\ue0b0",
 						Foreground:      "p:white",
 						Background:      "p:orange",
-						Properties: properties.Map{
-							properties.Style: "folder",
+						Options: options.Map{
+							options.Style: "folder",
 						},
 						Template: " \uea83 {{ path .Path .Location }} ",
 					},
@@ -62,7 +63,7 @@ func Default(warning bool) *Config {
 							"{{ if and (gt .Ahead 0) (gt .Behind 0) }}p:white{{ end }}",
 							"{{ if gt .Ahead 0 }}p:white{{ end }}",
 						},
-						Properties: properties.Map{
+						Options: options.Map{
 							segments.BranchTemplate:    "{{ trunc 25 .Branch }}",
 							segments.FetchStatus:       true,
 							segments.FetchUpstreamIcon: true,
@@ -87,8 +88,8 @@ func Default(warning bool) *Config {
 						BackgroundTemplates: []string{
 							exitBackgroundTemplate,
 						},
-						Properties: properties.Map{
-							properties.AlwaysEnabled: true,
+						Options: options.Map{
+							options.AlwaysEnabled: true,
 						},
 						Template: exitTemplate,
 					},
@@ -103,7 +104,7 @@ func Default(warning bool) *Config {
 						Foreground: "p:green",
 						Background: "transparent",
 						Template:   "\ue718 ",
-						Properties: properties.Map{
+						Options: options.Map{
 							segments.HomeEnabled:         false,
 							segments.FetchPackageManager: false,
 							segments.DisplayMode:         "files",
@@ -115,8 +116,8 @@ func Default(warning bool) *Config {
 						Foreground: "p:blue",
 						Background: "transparent",
 						Template:   "\ue626 ",
-						Properties: properties.Map{
-							properties.FetchVersion: false,
+						Options: options.Map{
+							options.FetchVersion: false,
 						},
 					},
 					{
@@ -125,8 +126,8 @@ func Default(warning bool) *Config {
 						Foreground: "p:yellow",
 						Background: "transparent",
 						Template:   "\ue235 ",
-						Properties: properties.Map{
-							properties.FetchVersion:  false,
+						Options: options.Map{
+							options.FetchVersion:     false,
 							segments.DisplayMode:     "files",
 							segments.FetchVirtualEnv: false,
 						},
@@ -177,8 +178,8 @@ func Default(warning bool) *Config {
 				Foreground:      "p:white",
 				Background:      "p:orange",
 				Template:        " \ue7ad {{ .Profile }}{{ if .Region }}@{{ .Region }}{{ end }} ",
-				Properties: properties.Map{
-					properties.DisplayDefault: true,
+				Options: options.Map{
+					options.DisplayDefault: true,
 				},
 				Tips: []string{"aws"},
 			},
@@ -190,17 +191,92 @@ func Default(warning bool) *Config {
 				Foreground:      "p:white",
 				Background:      "p:blue",
 				Template:        " \uebd8 {{ .Name }} ",
-				Properties: properties.Map{
-					properties.DisplayDefault: true,
+				Options: options.Map{
+					options.DisplayDefault: true,
 				},
 				Tips: []string{"az"},
 			},
 		},
 		Upgrade: &upgrade.Config{
-			Source:        upgrade.CDN,
-			DisplayNotice: true,
-			Auto:          true,
-			Interval:      cache.ONEWEEK,
+			Source:   upgrade.CDN,
+			Interval: cache.ONEWEEK,
+		},
+	}
+
+	return cfg
+}
+
+func Claude() *Config {
+	cfg := &Config{
+		hash:    1234567890, // placeholder hash value
+		Version: 4,
+		Blocks: []*Block{
+			{
+				Type:      Prompt,
+				Alignment: Left,
+				Segments: []*Segment{
+					{
+						Type:           PATH,
+						Style:          Diamond,
+						LeadingDiamond: "\ue0b6",
+						Foreground:     "p:white",
+						Background:     "p:orange",
+						Options: options.Map{
+							segments.DirLength:           3,
+							segments.FolderSeparatorIcon: "\ue0bb",
+							options.Style:                "fish",
+						},
+						Template: "{{ if .Segments.Git.Dir }} \uf1d2 <i><b>{{ .Segments.Git.RepoName }}{{ if .Segments.Git.IsWorkTree }} \ue21c{{ end }}</b></i>{{ $rel :=  .Segments.Git.RelativeDir }}{{ if $rel }} \ueaf7 {{ .Format $rel }}{{ end }}{{ else }} \uea83 {{ path .Path .Location }}{{ end }} ", //nolint:lll
+					},
+					{
+						Type:            GIT,
+						Style:           Diamond,
+						LeadingDiamond:  "<parentBackground,background>\ue0b0</>",
+						TrailingDiamond: "\ue0b4",
+						Foreground:      "p:black",
+						Background:      "p:green",
+						BackgroundTemplates: []string{
+							"{{ if or (.Working.Changed) (.Staging.Changed) }}p:yellow{{ end }}",
+							"{{ if and (gt .Ahead 0) (gt .Behind 0) }}p:red{{ end }}",
+							"{{ if gt .Ahead 0 }}#49416D{{ end }}",
+							"{{ if gt .Behind 0 }}#7A306C{{ end }}",
+						},
+						ForegroundTemplates: []string{
+							"{{ if or (.Working.Changed) (.Staging.Changed) }}p:black{{ end }}",
+							"{{ if or (gt .Ahead 0) (gt .Behind 0) }}p:white{{ end }}",
+						},
+						Options: options.Map{
+							segments.FetchStatus:       true,
+							segments.FetchUpstreamIcon: false,
+						},
+						Template: " {{ if .UpstreamURL }}{{ url .UpstreamIcon .UpstreamURL }} {{ end }}{{ .HEAD }}{{if .BranchStatus }} {{ .BranchStatus }}{{ end }}{{ if .Working.Changed }} \uf044 {{ nospace .Working.String }}{{ end }}{{ if .Staging.Changed }} \uf046 {{ .Staging.String }}{{ end }} ", //nolint:lll
+					},
+				},
+			},
+			{
+				Type:      Prompt,
+				Alignment: Right,
+				Segments: []*Segment{
+					{
+						Type:            CLAUDE,
+						Style:           Diamond,
+						LeadingDiamond:  "\ue0b6",
+						TrailingDiamond: "\ue0b4",
+						Foreground:      "p:black",
+						Background:      "p:blue",
+						Template:        " \U000f0bc9 {{ .Model.DisplayName }} \uf2d0 {{ .TokenUsagePercent.Gauge }} ",
+					},
+				},
+			},
+		},
+		Palette: color.Palette{
+			"black":  "#262B44",
+			"blue":   "#4B95E9",
+			"green":  "#59C9A5",
+			"orange": "#F07623",
+			"red":    "#D81E5B",
+			"white":  "#E0DEF4",
+			"yellow": "#F3AE35",
 		},
 	}
 
