@@ -2,19 +2,21 @@ package main
 
 import (
 	"bytes"
+	"fmt"
 	"testing"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/cli"
+	"github.com/jandedobbeleer/oh-my-posh/src/prompt"
 )
 
 func BenchmarkInit(b *testing.B) {
 	cmd := cli.RootCmd
 	// needs to be a non-existing file as we panic otherwise
-	cmd.SetArgs([]string{"init", "fish", "--print", "--config", "err.omp.json"})
+	cmd.SetArgs([]string{"init", "fish", "--print", "--silent"})
 	out := bytes.NewBufferString("")
 	cmd.SetOut(out)
 
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		_ = cmd.Execute()
 	}
 }
@@ -22,11 +24,13 @@ func BenchmarkInit(b *testing.B) {
 func BenchmarkPrimary(b *testing.B) {
 	cmd := cli.RootCmd
 	// needs to be a non-existing file as we panic otherwise
-	cmd.SetArgs([]string{"print", "primary", "--config", "err.omp.json", "--pwd", "/Users/jan/Code/oh-my-posh/src", "--shell", "fish"})
+	cmd.SetArgs([]string{"print", prompt.PRIMARY, "--pwd", "/Users/jan/Code/oh-my-posh/src", "--shell", "fish", "--silent"})
 	out := bytes.NewBufferString("")
 	cmd.SetOut(out)
 
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		_ = cmd.Execute()
 	}
+
+	fmt.Println("")
 }
